matminer.featurizers.utils.tests package — matminer 0.9.1 documentation

# matminer.featurizers.utils.tests package

## Submodules

## matminer.featurizers.utils.tests.test_grdf module

class matminer.featurizers.utils.tests.test_grdf.GRDFTests(methodName='runTest')

  Bases: `PymatgenTest`

  test_bessel()
  test_cosine()
  test_gaussian()
  test_histogram()
  test_load_class()
  test_sin()

## matminer.featurizers.utils.tests.test_oxidation module

class matminer.featurizers.utils.tests.test_oxidation.OxidationTest(methodName='runTest')

  Bases: `PymatgenTest`

  test_has_oxidation_states()

## matminer.featurizers.utils.tests.test_stats module

class matminer.featurizers.utils.tests.test_stats.TestPropertyStats(methodName='runTest')

  Bases: `TestCase`

  setUp()

    Hook method for setting up the test fixture before exercising it.

  test_avg_dev()
  test_geom_std_dev()
  test_holder_mean()
  test_kurtosis()
  test_maximum()
  test_mean()
  test_minimum()
  test_mode()
  test_quantile()
  test_range()
  test_skewness()
  test_std_dev()

## Module contents